.. openDAQ documentation master file, created by
   sphinx-quickstart on Wed Jul 22 14:54:24 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

openDAQ
=======

This is the documentation of the **openDAQ** Python package

Contents:

.. toctree::
   :maxdepth: 2

   usage
   installation

   opendaq

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

